@@ -1,10 +1,8 @@
 --
 -- TIMESTAMPTZ
 --
-
 CREATE TABLE TIMESTAMPTZ_TBL (
-    d1 timestamp(2
-) with time zone
+    d1 timestamp(2) with time zone
 );
 
 -- Test shorthand input values
@@ -15,7 +13,6 @@ CREATE TABLE TIMESTAMPTZ_TBL (
 -- NOTE: it is possible for this part of the test to fail if the transaction
 -- block is entered exactly at local midnight; then 'now' and 'today' have
 -- the same values and the counts will come out different.
-
 INSERT INTO TIMESTAMPTZ_TBL
     VALUES ('now');
 
@@ -40,27 +37,26 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 = timestamp WITH time zone 'today';
+    d1 = timestamp with time zone 'today';
 SELECT
     count(*) AS One
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 = timestamp WITH time zone 'tomorrow';
+    d1 = timestamp with time zone 'tomorrow';
 SELECT
     count(*) AS One
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 = timestamp WITH time zone 'yesterday';
+    d1 = timestamp with time zone 'yesterday';
 SELECT
     count(*) AS One
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 = timestamp(2
-)
-    WITH time zone 'now';
+    d1 = timestamp(2)
+    with time zone 'now';
 COMMIT;
 
 DELETE FROM TIMESTAMPTZ_TBL;
@@ -80,9 +76,8 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 = timestamp(2
-)
-    WITH time zone 'now';
+    d1 = timestamp(2)
+    with time zone 'now';
 COMMIT;
 
 DELETE FROM TIMESTAMPTZ_TBL;
@@ -243,7 +238,6 @@ SELECT
 
 -- non-DST
 -- Check date conversion and date arithmetic
-
 INSERT INTO TIMESTAMPTZ_TBL
     VALUES ('1997-06-10 18:32:01 PDT');
 
@@ -349,7 +343,6 @@ INSERT INTO TIMESTAMPTZ_TBL
 
 -- Alternative field order that we've historically supported (sort of)
 -- with regular and POSIXy timezone specs
-
 SELECT
     'Wed Jul 11 10:51:14 America/New_York 2001'::timestamptz;
 
@@ -387,14 +380,13 @@ SELECT
 -- out of range
 -- The upper boundary differs between integer and float timestamps, so no check
 -- Demonstrate functions and operators
-
 SELECT
     '' AS "48",
     d1
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 > timestamp WITH time zone '1997-01-02';
+    d1 > timestamp with time zone '1997-01-02';
 
 SELECT
     '' AS "15",
@@ -402,7 +394,7 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 < timestamp WITH time zone '1997-01-02';
+    d1 < timestamp with time zone '1997-01-02';
 
 SELECT
     '' AS one,
@@ -410,7 +402,7 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 = timestamp WITH time zone '1997-01-02';
+    d1 = timestamp with time zone '1997-01-02';
 
 SELECT
     '' AS "63",
@@ -418,7 +410,7 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 != timestamp WITH time zone '1997-01-02';
+    d1 != timestamp with time zone '1997-01-02';
 
 SELECT
     '' AS "16",
@@ -426,7 +418,7 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 <= timestamp WITH time zone '1997-01-02';
+    d1 <= timestamp with time zone '1997-01-02';
 
 SELECT
     '' AS "49",
@@ -434,11 +426,11 @@ SELECT
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 >= timestamp WITH time zone '1997-01-02';
+    d1 >= timestamp with time zone '1997-01-02';
 
 SELECT
     '' AS "54",
-    d1 - timestamp WITH time zone '1997-01-02' AS diff
+    d1 - timestamp with time zone '1997-01-02' AS diff
 FROM
     TIMESTAMPTZ_TBL
 WHERE
@@ -447,33 +439,32 @@ WHERE
 
 SELECT
     '' AS date_trunc_week,
-    date_trunc('week', timestamp WITH time zone '2004-02-29 15:44:17.71393') AS week_trunc;
+    date_trunc('week', timestamp with time zone '2004-02-29 15:44:17.71393') AS week_trunc;
 
 SELECT
     '' AS date_trunc_at_tz,
-    date_trunc('day', timestamp WITH time zone '2001-02-16 20:38:40+00', 'Australia/Sydney') AS sydney_trunc;
+    date_trunc('day', timestamp with time zone '2001-02-16 20:38:40+00', 'Australia/Sydney') AS sydney_trunc;
 
 -- zone name
 SELECT
     '' AS date_trunc_at_tz,
-    date_trunc('day', timestamp WITH time zone '2001-02-16 20:38:40+00', 'GMT') AS gmt_trunc;
+    date_trunc('day', timestamp with time zone '2001-02-16 20:38:40+00', 'GMT') AS gmt_trunc;
 
 -- fixed-offset abbreviation
 SELECT
     '' AS date_trunc_at_tz,
-    date_trunc('day', timestamp WITH time zone '2001-02-16 20:38:40+00', 'VET') AS vet_trunc;
+    date_trunc('day', timestamp with time zone '2001-02-16 20:38:40+00', 'VET') AS vet_trunc;
 
 -- variable-offset abbreviation
 -- Test casting within a BETWEEN qualifier
-
 SELECT
     '' AS "54",
-    d1 - timestamp WITH time zone '1997-01-02' AS diff
+    d1 - timestamp with time zone '1997-01-02' AS diff
 FROM
     TIMESTAMPTZ_TBL
 WHERE
-    d1 BETWEEN timestamp WITH time zone '1902-01-01'
-    AND timestamp WITH time zone '2038-01-01';
+    d1 BETWEEN timestamp with time zone '1902-01-01'
+    AND timestamp with time zone '2038-01-01';
 
 SELECT
     '' AS "54",
@@ -757,7 +748,6 @@ RESET TimeZone;
 -- These tests rely on the knowledge that MSK (Europe/Moscow standard time)
 -- moved forwards in Mar 2011 and backwards again in Oct 2014.
 --
-
 SET TimeZone TO 'UTC';
 
 SELECT
@@ -947,14 +937,12 @@ SELECT
 
 -- 2010-01-01 12:34:56.789012+00
 -- edge cases
-
 SELECT
     to_timestamp(- 210866803200);
 
 --   4714-11-24 00:00:00+00 BC
 -- upper limit varies between integer and float timestamps, so hard to test
 -- nonfinite values
-
 SELECT
     to_timestamp(' Infinity'::float);
 
@@ -1079,7 +1067,6 @@ SELECT
 --
 -- Test that AT TIME ZONE isn't misoptimized when using an index (bug #14504)
 --
-
 CREATE temp TABLE tmptz (
     f1 timestamptz PRIMARY KEY
 );
